import {Locale, ValidationErrorMessage} from './types';
declare const ErrorCodes: {
  unknownError: string;
  recaptchaMaxRetryOver: string;
  captchaGenerateTokenMaxRetryOver: string;
  captchaInitializationMaxRetryOver: string;
  recaptchaScriptLoadFailed: string;
  recaptchaLoadTimeout: string;
  recaptchaInitiationTimeout: string;
  missingMandatoryParameters: string;
  invalidFieldType: string;
  fieldAlreadyExists: string;
  fieldNotAllowed: string;
  noFieldsToMount: string;
  missingFields: string;
  moduleNotSupported: string;
  moduleNotLoaded: string;
  invalidComponentType: string;
  invalidSelector: string;
  noContainerElement: string;
  containerElementNotFound: string;
  componentNotRegistered: string;
  componentNotFound: string;
  invalidListener: string;
  frameNotSpecified: string;
  validationFailed: string;
  componentAlreadyPresent: string;
  errorMountingMaster: string;
  instanceAlreadyExists: string;
  unknownMessageOrigin: string;
  sendMessageError: string;
  sendMessageMismatchError: string;
  noMessageTarget: string;
  receiveMessageError: string;
  responseError: string;
  responseMismatchError: string;
  replyTimeout: string;
  missingPublishableKey: string;
  masterNotMountedForComponents: string;
  cardNumberInvalid: string;
  cardNumberIncomplete: string;
  invalidCard: string;
  cardExpiryPast: string;
  cardExpiryInvalid: string;
  cardExpiryIncomplete: string;
  cardCvvIncomplete: string;
  cardCvvInvalid: string;
  invalidAriaLabel: string;
  componentNotMounted: string;
  componentMounting: string;
  componentAlreadyMounted: string;
  unknownProperty: string;
  invalidValueProvided: string;
  unknownFieldProperty: string;
  unknownCssProperty: string;
  unknownCssClass: string;
  incorrectClass: string;
  unknownFontProp: string;
  invalidFont: string;
  invalidSrcUrl: string;
  fontUrlNotWhitelisted: string;
  fontNotInPx: string;
  invalidCssValue: string;
  invalidCssColor: string;
  localeNotSupported: string;
  invalidFields: string;
  invalidPlaceholder: string;
  invalidPlaceholderValue: string;
  unknownStyleProperty: string;
  invalidStyles: string;
  /** THREE-D-SECURE ERRORS */
  invalidPaymentIntent: string;
  missingCardDetails: string;
  invalidCardReferenceId: string;
  unknownPaymentAttemptStatus: string;
  invalidAdyenCheckoutInstance: string;
  missingAdyenPaymentInfo: string;
  missingAdyenRedirectInfo: string;
  invalidAdyenOriginKey: string;
  missingBraintreePaymentInfo: string;
  invalidBraintreeInstance: string;
  missingBraintreeInstance: string;
  missingBraintree3DSecureInstance: string;
  invalidBraintreeHostedFields: string;
  invalidBraintreeTokenizedCard: string;
  noBraintreeTokenizedCard: string;
  missingNonceForBraintreeReferenceId: string;
  failedBraintreeThreeDSecureAuth: string;
  scriptLoadError: string;
  missingSpreedlyPaymentInfo: string;
  missingBluesnapPaymentInfo: string;
  invalidStripeInstance: string;
  missingStripePaymentInfo: string;
  missingStripeInstance: string;
  missingEbanxPaymentInfo: string;
  invalidEbanxDocument: string;
  missingGlobalPaymentInfo: string;
  missingDlocalPaymentInfo: string;
  invalidDlocalDocument: string;
  missingPayfurlCountryCode: string;
  missingChargebeePaymentsPaymentInfo: string;
  invalidChargebeePaymentCheckoutInstance: string;
  missingVantivPaymentInfo: string;
  missingIDealCurrency: string;
  missingIDealIssuerBank: string;
  missingPaymentIntentForMountButton: string;
  missingTokenInfoInPaymentData: string;
  missingDotpayCurrency: string;
  missingDotpayIssuerBank: string;
  missingIngenicoDirectPaymentInfo: string;
  missingWorldPayPaymentInfo: string;
  missingWorldPayEmailInfo: string;
  missingWorldPayCardHolderInfo: string;
  missingMolliePaymentInfo: string;
  missingMollieCardHolderInfo: string;
  missingVatParams: string;
  applePayNotSupported: string;
  applePayPaymentsNotAvailable: string;
  applePayElementNotFound: string;
  missingRazorPayPaymentInfo: string;
  missingRazorPayEmailInfo: string;
  missingRazorPayPhoneInfo: string;
  missingRazorPayCardHolderInfo: string;
  unsupportedDirectDebitScheme: string;
  unsupportedDirectDebitGateway: string;
  missingDirectDebitPaymentInfo: string;
  invalidOrMissingDirectDebitPaymentInfo: string;
  plaidNotsupported: string;
  missingBancontactAdyenPaymentInfo: string;
  missingKlarnaPayNowBillingAddressInfo: string;
  missingBankOfAmericaPaymentInfo: string;
  missingBankOfAmericaEmailInfo: string;
  missingBoletoPaymentInfo: string;
  invalidOrMissingBoletoPaymentInfo: string;
  missingPayfurlPaymentInfo: string;
  venmoNotSupportedByBrowser: string;
  venmoAppCanceled: string;
  venmoCanceled: string;
  invalidOrMissingFasterPymtsPaymentInfo: string;
  missingFasterPymtsCountryCode: string;
  eitherCurrencyOrGwAccIdRequiredForFasterPymts: string;
  invalidOrMissingPayToPaymentInfo: string;
  missingPayToCountryCode: string;
  eitherCurrencyOrGwAccIdRequiredForPayTo: string;
  invalidOrMissingSepaInstantTransferPaymentInfo: string;
  missingSepaInstantTransferCountryCode: string;
  eitherCurrencyOrGwAccIdRequiredForSepaInstantTransfer: string;
  missingPayComPaymentInfo: string;
  invalidOrMissingPayComCardPaymentInfo: string;
  /**
   * Component Errors
   */
  invalidComponent: string;
  missingPayPaymentInfo: string;
  missingCardHolderInfo: string;
};
export declare enum ErrorType {
  ApiError = 'ApiError',
  ClientError = 'ClientError',
  GatewayError = 'GatewayError',
}
export declare type ErrorObject = {
  name?: string;
  message?: string;
  code?: string;
  type?: ErrorType;
  stack?: string;
  data?: any;
  detail?: any;
};
export declare const DefaultError: ErrorObject;
export declare function defaultError(): CbError;
export interface CbError extends Error {
  message: string;
  name: string;
  stack: string;
  data: any;
  type: ErrorType;
  code: string;
  detail: string;
  constructor(err?: any, data?: any, locale?: any, ...args: any[]);
}
export declare const Warn: (err: string, data?: any, locale?: Locale) => void;
export declare const ValidationError: (code: string, locale: Locale) => ValidationErrorMessage;
export default ErrorCodes;
