import {HostedFields, Entity, Currency} from './enums';
import {ComponentOptions, StyleBlock, Styles, Classes, FontFace, Locale, Placeholder, AriaLabel, Fields} from './types';
import {noop} from './dom-utils';
import '@/helpers/polyfills';
export declare function addStyle(name: string, value: string): string;
export interface Options {
  [HostedFields.Options.style]?: Styles;
  [HostedFields.Options.placeholder]?: Placeholder | string;
  [HostedFields.Options.ariaLabel]?: AriaLabel | string;
}
export declare function sanitizeInput<T extends Options>(inputOptions: T, entityType: Entity): T;
declare const Sanitizer: {
  color: (prop: string, value: string, parent: StyleBlock) => void;
  webkitTextColor: (prop: string, value: string, parent: StyleBlock) => void;
  iconColor: (prop: string, value: string, parent: StyleBlock) => void;
  fontSize: (prop: string, value: string, parent: StyleBlock) => void;
  fontFamily: typeof noop;
  fontSmoothing: (prop: string, value: string, parent: StyleBlock) => void;
  fontStyle: (prop: string, value: string, parent: StyleBlock) => void;
  fontVariant: (prop: string, value: string, parent: StyleBlock) => void;
  fontWeight: (prop: string, value: string, parent: StyleBlock) => void;
  letterSpacing: (prop: string, value: string, parent: StyleBlock) => void;
  textAlign: (prop: string, value: string, parent: StyleBlock) => void;
  textDecoration: typeof noop;
  textShadow: typeof noop;
  textTransform: (prop: string, value: string, parent: StyleBlock) => void;
  lineHeight: (prop: string, value: string, parent: StyleBlock) => void;
  icon(icon: boolean, parent: ComponentOptions): void;
  currency(currencyKey: Currency, parent: ComponentOptions, type: Entity): void;
  classes(classes: Classes, parent: ComponentOptions, type: Entity): void;
  style(styles: Styles): void;
  fonts(fonts: Array<FontFace>, parent: ComponentOptions, type: Entity, whitelist?: Array<string>): void;
  field(field: Fields, parent: ComponentOptions, type: Entity): void;
  locale(locale: Locale, parent: ComponentOptions, type: Entity): void;
  placeholder(placeholder: Placeholder, parent: ComponentOptions, type: Entity): void;
  ariaLabel(ariaLabel: AriaLabel, parent: ComponentOptions, type: Entity): void;
  htmlSafeText: (text: string) => string;
  fontURL: (url: string, whitelist?: any[]) => string;
  fontSrcContents: (key: string, value: string, whitelist: Array<string>) => string;
  fontSrc: (src: string, whitelist: string[]) => string;
};
export default Sanitizer;
