import ComponentField from './component-field';
import {BINData, ComponentOptions, EventMessage, FieldOptions, FontFace} from '../common/types';
import {Card, ComponentMountStatus, Events} from '../common/enums';
import {CardComponentInterface, ComponentType, ThreeDSHandler} from '../common/base-types';
import {AdditionalData, Callbacks, PaymentIntent} from '../../extensions/three_domain_secure/common/types';
interface ValidationError {
  errorMsg: string;
  isValid: boolean;
}
export default class CardComponent {
  fields: ComponentField[];
  name: string;
  type: ComponentType.Card;
  status: ComponentMountStatus;
  id: string;
  options: ComponentOptions;
  gatewayConfig: any;
  listeners: {
    focus?: Function;
    blur?: Function;
    change?: Function;
    ready?: Function;
  };
  fonts: FontFace[];
  combinedField: ComponentField;
  container: HTMLElement;
  threeDSHandler: ThreeDSHandler;
  constructor(componentOptions?: ComponentOptions);
  createField(fieldType: Card.ComponentFieldType, fieldOptions?: FieldOptions): ComponentField;
  getFields(): ComponentField[];
  deregister(id: any): void;
  at(domElement: string | HTMLElement): CardComponent;
  on(eventType: Events, eventCallback: Function): this;

  focus(): void;
  blur(): void;
  clear(): void;
  isMounted(): boolean;
  update(options: ComponentOptions): void;
  mount(domElement: string | HTMLElement): Promise<boolean>;
  getErrorMsgForEmptyvalue(field: any): string;
  filterCardData(fieldValidationStatues: any): ValidationError;
  validateCardDetails(): Promise<boolean>;

  tokenize(data?: any): Promise<any>;
  authorizeWith3ds(
    paymentIntent: PaymentIntent,
    additionalData?: AdditionalData,
    callbacks?: Callbacks
  ): Promise<PaymentIntent>;
  get3DSHandler(): ThreeDSHandler;
  framesCreated(): string[];
  delegateEvent(data: EventMessage): void;
  getBinData(): BINData | undefined;
  destroy(): Promise<void | boolean[]>;
}
export {};
