import {ResponseInnerMessage, ActionInnerMessage, ReplyMessageOptions} from '../common/types';
import CbIframe from './cb-iframe';
import ComponentField from './component-field';
import IDealField from './ideal-field';
export declare const CHILD_IFRAME_NAME: (name: string, id: string) => string;
export interface CbIframeClientInterface {
  createMasterFrame(): Promise<any>;
  createCbFrame(componentField: ComponentField, containerElement: HTMLElement): Promise<CbIframe>;
  register(message: ActionInnerMessage, frame: CbIframe): Promise<ResponseInnerMessage>;
  register(message: ActionInnerMessage, frame: CbIframe): Promise<ResponseInnerMessage>;
  send(message: ActionInnerMessage, name: string, options?: ReplyMessageOptions): Promise<ResponseInnerMessage>;
  listen(event: MessageEvent): any;
  deregister(name: string): any;
}
interface CbIframeClient {
  constructor();
  createMasterFrame(): Promise<any>;
  /**
   * replaces existing div element with the given id with a corresponding iframe element
   */
  createCbFrame(componentField: ComponentField, containerElement: HTMLElement): Promise<CbIframe>;
  createIDealFrame(componentField: IDealField, containerElement: HTMLElement, opts: any): Promise<CbIframe>;
  /**
   * For registering a component/Field to Master
   * @param message - action message
   * @param name - iframe name
   */
  register(message: ActionInnerMessage, frame: CbIframe): Promise<ResponseInnerMessage>;

  /**
   * Message communication with master
   * @param message - action message
   * @param name - iframe name
   * @param options - message Options
   */
  send(message: ActionInnerMessage, name: string, options?: ReplyMessageOptions): Promise<ResponseInnerMessage>;
  listen(event: MessageEvent): void;
  deregister(name: string): void;
}
declare const cbIframeClient: CbIframeClient;
export default cbIframeClient;
