import {
  PaymentIntent,
  Address,
  Callbacks,
  PaymentInfo,
  PaymentAttempt,
  PaymentIntentResponse,
  PaymentAttemptStatus,
  GatewayInstances,
} from './types';
import CallbackHandler from './callback';
import RedirectHandler from '../auth-redirect/handler';
import {PaymentOptions} from '../../hosted_fields/common/base-types';
export default class PaymentIntentHandler extends RedirectHandler {
  callbackHandler: CallbackHandler;

  protected paymentInfo: PaymentInfo | any;

  redirectTimeout: number;

  /**
   * default implementations, to be overridden in the payment/ gateway handler
   */
  initPayment(): Promise<any>;
  validate(): Promise<any>;
  getPaymentData(): any;
  mount(options: any): Promise<boolean>;
  mountPaymentButton(id: string, options: any): Promise<any>;

  constructor(paymentIntent?: PaymentIntent, gatewayInstances?: GatewayInstances);

  initCallbacks(paymentInfo: PaymentInfo, callbacks?: Callbacks): void;
  sanitizeData(): void;
  getGatewayHandler(paymentIntent?: PaymentIntent, gatewayInstances?: GatewayInstances): Promise<PaymentIntentHandler>;
  getDirectDebitGatewayHandler(
    paymentIntent?: PaymentIntent,
    gatewayInstances?: GatewayInstances
  ): Promise<PaymentIntentHandler>;
  /**
   * @param options - type PaymentOptions or any (type ANY to support for bancontact)
   * @returns
   */
  handlePayment(options: PaymentOptions | any): Promise<any>;
  /**
   * @param options - type PaymentInfo or any (type ANY to support for bancontact)
   * @returns
   */
  initiateAuthorization(paymentInfo: PaymentInfo | any, callbacks?: Callbacks): Promise<PaymentIntent>;
  protected cancelPayment(reason?: string): Promise<any>;
  protected confirmPayment(data?: any): Promise<any>;
  protected handleConfirmPaymentResponse: (intentResponse: PaymentIntentResponse) => Promise<any>;

  getPaymentIntent(): PaymentIntent;
  setPaymentIntent(paymentIntent: PaymentIntent): void;
  updatePaymentIntent(paymentIntent: PaymentIntent): void;

  protected stopPoll(data?: any): Promise<import('../../hosted_fields/common/types').ResponseInnerMessage>;
  protected pollForAuthCompletion(): Promise<import('../../hosted_fields/common/types').ResponseInnerMessage>;
}
