export declare type CommonSubscriptionEstimate = {
  customer?: Customer;
  subscription?: Subscription;
  billing_cycles?: number;
  terms_to_charge?: number;
  invoice_immediately?: boolean;
  billing_alignment_mode?: 'immediate' | 'delayed';
  shipping_address?: ShippingAddress;
  billing_address?: BillingAddress;
  coupon_ids?: Array<string>;
  addons?: Array<Addon>;
  event_based_addons?: Array<EventBasedAddon>;
  mandatory_addons_to_remove?: Array<string>;
};
export declare type CreateSubscriptionEstimate = CommonSubscriptionEstimate & {
  client_profile_id?: string;
};
export declare type UpdateSubscriptionEstimate = CommonSubscriptionEstimate & {
  replace_addon_list?: boolean;
  reactivate_from?: number;
  replace_coupon_list?: boolean;
  prorate?: boolean;
  end_of_term?: boolean;
  force_term_reset?: boolean;
  reactivate?: boolean;
  include_delayed_charges?: boolean;
  use_existing_balances?: boolean;
};
export declare type SubscriptionRenewalEstimate = {
  id: string;
  subscription?: {
    id: string;
  };
  include_delayed_charges?: boolean;
  use_existing_balances?: boolean;
  ignore_scheduled_cancellation?: boolean;
  ignore_scheduled_changes?: boolean;
};
export declare type Subscription = {
  id?: string;
  plan_id: string;
  plan_quantity?: number;
  plan_unit_price?: number;
  setup_fee?: number;
  start_date?: number;
  trial_end?: number;
};
export declare type Address = {
  line1?: string;
  line2?: string;
  line3?: string;
  city?: string;
  state_code?: string;
  zip?: string;
  country?: string;
  validation_status?: 'not_validated' | 'valid' | 'partially_valid' | 'invalid';
};
export declare type BillingAddress = Address;
export declare type ShippingAddress = Address;
export declare type Customer = {
  vat_number?: string;
  registered_for_gst?: string;
  taxability?: 'taxable' | 'exempt';
  entity_code?: string;
  exempt_number?: string;
  exemption_details?: any;
  customer_type?: 'residential' | 'business' | 'senior_citizen' | 'industrial';
};
export declare type Addon = {
  id?: string;
  quantity?: number;
  unit_price?: number;
  billing_cycles?: number;
  trial_end?: number;
};
export declare type EventBasedAddon = {
  id?: string;
  quantity?: number;
  unit_price?: number;
  service_period_in_days?: number;
  on_event?: 'subscription_creation' | 'subscription_trial_start' | 'plan_activation' | 'subscription_activation';
  charge_once?: boolean;
  charge_on?: 'immediately' | 'on_event';
};
export declare type VatValidationParams = {
  country: string;
  vat_number: string;
};
