export interface StripeInstance {
  [key: string]: any;
}
export interface StripeGatewayCredential {
  publishable_key: string;
  apple_pay?: {
    merchant_country_code?: string;
    stripe_account_id?: string;
  };
}
export interface CheckoutComGatewayCredential {
  apple_pay: {
    merchant_country_code: string;
    copy_billing_address: boolean;
    copy_shipping_address: boolean;
    copy_contact: boolean;
  };
}
export interface StripePaymentRequest extends PaymentRequest {
  total: ApplePayLineItem;
  update: (options: StripeUpdatePaymentRequestOptions) => void;
  on: (eventName: string, callback: (event: StripePaymentEvent) => any) => any;
  canMakePayment: () => Promise<boolean>;
  show: () => void;
}
export interface StripeShippingAddress {
  country: string;
  addressLine?: Array<string>;
  region?: string;
  city?: string;
  postalCode?: string;
  recipient?: string;
  phone?: string;
  sortingCode?: string;
  dependentLocality?: string;
}
export interface StripeBillingAddress {
  country: string;
  line1?: string;
  line2?: string;
  city?: string;
  postal_code?: string;
  state?: string;
}
export interface StripeBillingDetails {
  email?: string;
  name?: string;
  phone?: string;
  address: StripeBillingAddress;
}
export interface StripePaymentEvent {
  paymentMethod?: StripePaymentMethod;
  complete: (status: string) => void;
  payerName?: string;
  payerEmail?: string;
  walletName?: string;
  shippingAddress?: StripeShippingAddress;
  shippingOption?: StripeShippingOption;
  updateWith?: (updateDetails: any) => void;
}
interface StripeCardDetails {
  last4: string;
}
export interface StripeElementsInstance {
  create: (type: string, payload: any) => any;
}
export interface StripePaymentRequestButton {
  mount: (querySelector: string) => void;
}
export interface StripePaymentMethod {
  id: string;
  card: StripeCardDetails;
  billing_details?: StripeBillingDetails;
}
export interface StripePaymentRequestOptions {
  requestPayerName?: boolean;
  requestPayerEmail?: boolean;
  requestPayerPhone?: boolean;
  requestShipping?: boolean;
  totalLabel?: string;
  displayItems?: Array<ApplePayLineItem>;
  shippingOptions?: Array<StripeShippingOption>;
  merchantCountryCode?: string;
  applePayRequest?: StripeApplePayRequest;
  onshippingmethodselected?: (event: any, callback: any) => void;
  onshippingcontactselected?: (event: any, callback: any) => void;
  onpaymentmethodselected?: (event: any, callback: any) => void;
}
export interface StripeApplePayRequest {
  recurringPaymentRequest?: ApplePayRecurringPaymentRequest;
}
export interface StripeMountOptions {
  locale?: string;
  buttonColor?: string;
  buttonType?: string;
}
export interface StripeError {
  type?: string;
  code?: string;
  message?: string;
}
export interface StripePaymentIntent {
  id: string;
  amount: number;
  client_secret: string;
  livemode: boolean;
  status: string;
}
export interface StripeConfirmResult {
  error?: StripeError;
  paymentIntent?: StripePaymentIntent;
}
export declare enum PaymentCompleteStatus {
  FAIL = 'fail',
  SUCCESS = 'success',
}
export interface StripeShippingOption {
  id: string;
  label: string;
  detail?: string;
  amount?: string;
}
export interface StripeUpdatePaymentRequestOptions {
  currency?: string;
  total?: ApplePayLineItem;
  displayItems?: Array<ApplePayLineItem>;
  shippingOptions?: Array<StripeShippingOption>;
}
export interface BraintreeApplePayInstance {
  createPaymentRequest: (options: any) => any;
  performValidation: (any: any) => any;
  tokenize: (any: any) => any;
}
export interface BraintreeMountOptions {
  requestBilling?: boolean;
  storeName?: string;
}
export declare type BraintreeApplePayOptions = StripePaymentRequestOptions & StripeMountOptions & BraintreeMountOptions;
export declare type BraintreeApplePaySession = any;
export declare type BraintreePaymentRequest = any;
export declare type BraintreeClientInstance = any;
export declare type CheckoutComApplePayOptions = StripePaymentRequestOptions &
  StripeMountOptions &
  BraintreeMountOptions;
export declare type CheckouComApplePaySession = any;
export declare type PaymentRequest = {
  merchantCapabilities?: Array<String>;
  supportedNetworks?: Array<String>;
  countryCode: String;
  requiredBillingContactFields: Array<String>;
  billingContact: Array<String>;
  requiredShippingContactFields: Array<String>;
  shippingContact: Array<String>;
  total: Object;
  lineItems: Array<Object>;
  currencyCode: String;
};
export interface AddressContact {
  addressLines?: Array<string>;
  administrativeArea?: string;
  country?: string;
  countryCode?: string;
  familyName?: string;
  givenName?: string;
  locality?: string;
  phoneticFamilyName?: string;
  phoneticGivenName?: string;
  postalCode?: string;
  subAdministrativeArea?: string;
  subLocality?: string;
  emailAddress?: string;
  phoneNumber?: string;
}
export interface ApplePaymentEvent {
  payment: {
    billingContact?: AddressContact;
    shippingContact?: AddressContact;
    token: {
      paymentData?: {
        data?: string;
        header?: object;
        signature?: string;
        version?: string;
      };
      paymentMethod?: {
        displayName?: string;
        network?: string;
        type?: string;
      };
      transactionIdentifier?: string;
    };
  };
}
export interface BraintreeDeviceDataCollectorInstance {
  deviceData: any;
}
export interface AdyenApplePayConfiguration {
  amount: object;
  countryCode: string;
  buttonType: string;
  buttonColor: string;
  recurringPaymentRequest?: ApplePayRecurringPaymentRequest;
  onClick: (resolve: any, reject: any) => Promise<unknown>;
  onValidateMerchant?: (resolve: any, reject: any, validationURL: any) => void;
  onSubmit: (state: any, dropin: any) => void;
  onAuthorized: (resolve: any, reject: any, event: any) => void;
  requiredBillingContactFields?: Array<string>;
  requiredShippingContactFields?: Array<string>;
}
export declare enum ApplePayButtonType {
  ADD_MONEY = 'add-money',
  BOOK = 'book',
  BUY = 'buy',
  CHECKOUT = 'check-out',
  CONTINUE = 'continue',
  CONTRIBUTE = 'contribute',
  DONATE = 'donate',
  ORDER = 'order',
  PAY = 'pay',
  PLAIN = 'plain',
  RELOAD = 'reload',
  RENT = 'rent',
  SETUP = 'set-up',
  SUBSCRIBE = 'subscribe',
  SUPPORT = 'support',
  TIP = 'tip',
  TOP_UP = 'top-up',
}
export declare enum ApplePayButtonColor {
  WHITE = 'white',
  WHITE_OUTLINE = 'white-outline',
  BLACK = 'black',
}
export declare type ApplePayMountOptions = {
  locale?: string;
  buttonType?: ApplePayButtonType;
  buttonColor?: ApplePayButtonColor;
  requestBilling?: boolean;
  requestShipping?: boolean;
  requestPayerEmail?: boolean;
  recurringPaymentRequest?: ApplePayRecurringPaymentRequest;
  onshippingmethodselected?: (event: any, callback: (update: ApplePayShippingMethodUpdate) => any) => void;
  onshippingcontactselected?: (event: any, callback: (update: ApplePayShippingContactUpdate) => any) => void;
  onpaymentmethodselected?: (event: any, callback: (update: ApplePayPaymentMethodUpdate) => any) => void;
};
export declare type ApplePayShippingMethodUpdate = {
  newTotal: ApplePayLineItem;
  newLineItems?: Array<ApplePayLineItem>;
};
export declare type ApplePayShippingContactUpdate = {
  newTotal: ApplePayLineItem;
  newLineItems?: Array<ApplePayLineItem>;
};
export declare type ApplePayPaymentMethodUpdate = {
  newTotal: ApplePayLineItem;
  newLineItems?: Array<ApplePayLineItem>;
};
export interface ApplePayRecurringPaymentRequest {
  paymentDescription: string;
  regularBilling: ApplePayLineItem;
  trialBilling?: ApplePayLineItem;
  billingAgreement?: string;
  managementURL: string;
  tokenNotificationURL?: string;
}
export declare enum ApplePayLineItemType {
  FINAL = 'final',
  PENDING = 'pending',
}
export declare enum ApplePayPaymentTiming {
  IMMEDIATE = 'immediate',
  RECURRING = 'recurring',
  DEFERRED = 'deferred',
  AUTOMATIC_RELOAD = 'automaticReload',
}
export declare enum ApplePayRecurringPaymentDateUnit {
  YEAR = 'year',
  MONTH = 'month',
  DAY = 'day',
  HOUR = 'hour',
  MINUTE = 'minute',
}
export interface ApplePayLineItem {
  type?: ApplePayLineItemType;
  label: string;
  amount: number;
  paymentTiming?: ApplePayPaymentTiming;
  recurringPaymentStartDate?: Date;
  recurringPaymentIntervalUnit?: ApplePayRecurringPaymentDateUnit;
  recurringPaymentIntervalCount?: number;
  recurringPaymentEndDate?: Date;
  deferredPaymentDate?: Date;
  automaticReloadPaymentThresholdAmount?: string;
}
export {};
